Parsers
=======

Multi-framework mutation report parsers and framework auto-detection.

.. automodule:: parsers
   :members:
   :show-inheritance:

.. automodule:: parsers.detection
   :members:
   :show-inheritance:

.. automodule:: parsers.stryker_parser
   :members:
   :show-inheritance:

.. automodule:: parsers.mutmut_parser
   :members:
   :show-inheritance:

.. automodule:: parsers.cosmic_ray_parser
   :members:
   :show-inheritance:

.. automodule:: parsers.poodle_parser
   :members:
   :show-inheritance:

.. automodule:: parsers.universalmutator_parser
   :members:
   :show-inheritance:
